Learn R Programming

RTopper (version 1.18.0)

gseResultsSep: A list of separated gene set enrichment p-values to be used to run the examples in the RTopper package

Description

A list containing distinct named numeric vectors corresponding to the gene set enrichment p-value separately computed with runBatchGSE for each distinct data set. Note that for each data set there are two set of p-values, one for GO and one for KEGG. These separate p-values can be combined across data sets by the combineGSE function. Can be used as input to adjustPvalGSE.

Usage

data(gseResultsSep)

Arguments

Format

This object is a list of length four: "dat.affy": a list of legnth two: "go" is a numeric vector of length 5, containing the p-values resulting from gene set enrichment analysis of 5 GO terms on Affymetrix gene expression data; "keg" is a numeric vector of length 5, containing the p-values resulting from gene set enrichment analysis of 5 KEGG pathways on Affymetrix gene expression data; "dat.agilent": a list of legnth two: "go" is a numeric vector of length 5, containing the p-values resulting from gene set enrichment analysis of 5 GO terms on Agilent gene expression data; "keg" is a numeric vector of length 5, containing the p-values resulting from gene set enrichment analysis of 5 KEGG pathways on Agilent gene expression data; "dat.cnvHarvard": a list of legnth two: "go" is a numeric vector of length 5, containing the p-values resulting from gene set enrichment analysis of 5 GO terms on Harvard CNV data; "keg" is a numeric vector of length 5, containing the p-values resulting from gene set enrichment analysis of 5 KEGG pathways on Harvard CNV data; "dat.cnvMskcc": a list of legnth two: "go" is a numeric vector of length 5, containing the p-values resulting from gene set enrichment analysis of 5 GO terms on MSKCC CNV data; "keg" is a numeric vector of length 5, containing the p-values resulting from gene set enrichment analysis of 5 KEGG pathways on MSKCC CNV data;

Computed using the runBatchGSE function from the TCGA data contained in sepScores and fgsList.

Examples

Run this code
data(gseResultsSep)
class(gseResultsSep)
names(gseResultsSep)
str(gseResultsSep)

Run the code above in your browser using DataLab